.. _api:

API
===

All public methods included in the module. See the :ref:`examples` pages for
some usage examples.

.. module:: momoko


BlockingClient Object
---------------------

.. autoclass:: momoko.BlockingClient
   :members:
   :inherited-members:


AsyncClient Object
------------------

.. autoclass:: momoko.AsyncClient
   :members:
   :inherited-members:


BlockingPool Object
-------------------

.. autoclass:: momoko.BlockingPool
   :members:
   :inherited-members:


AsyncPool Object
----------------

.. autoclass:: momoko.AsyncPool
   :members:
   :inherited-members:


AsyncConnection Object
----------------------

.. autoclass:: momoko.pools.AsyncConnection
   :members:
   :inherited-members:


QueryChain Object
-----------------

.. autoclass:: momoko.utils.QueryChain
   :members:
   :inherited-members:


BatchQuery Object
-----------------

.. autoclass:: momoko.utils.BatchQuery
   :members:
   :inherited-members:
